<?php
require('fpdf.php');

class PDF_MC_Table extends FPDF
{
    var $widths;
    var $aligns;
    var $fill;

    var $razonSocial = "Almacen Sustentable S.A. de C.V.";
    var $direccion = "
Av. Perdo Ramirez #200-11 C. Valle Oriente
San Pedro Garza Garcia
Nuebo León
México 66269";



    var $terms = "Términos y Condiciones
        ° Precios de la cotización en Dólares Americanos
        ° Se requiere orden de compra para trámite de pedido.
        ° Los productos no se encuentran reservados, puede cambiar su disponibilidad sin previo aviso
        ° LAB Monterrey N.L. / Guadalajara Jalisco.
        ° Pagos en MN, se considerara el tipo de cambio oficial el día de pago de acuerdo a HSBC
        https://www.hsbc.com.mx/1/2/es/personas/divisas (a la venta.)
        ° Precios incluyen IVA 16%
        ° Pago: 100% anticipado o sobre pedido 50% anticipado y 50% contra notificación de embarque.
        ° Procesamiento de orden de compra una vez verificado el depósito o transferencia bancaria.
        ° Tiempo de embarque sujeto a disponibilidad del producto, 5 días hábiles sí el equipo se encuentra
        disponible en stock (verificar con representante de ventas), más tiempo de embarque por parte de servicio de
        flete.
        ° Maniobras de embarque en destino y seguro a cargo del comprador.
        ° Se recomienda que cualquier cantidad y material embarcado este asegurado.
        ° Vigencia 15 días a partir de emisión de este documento.
        Lic. Jorge Castillo
        Coordinador Regional Centro
        Almacén Sustentable S.A de C.V
        Tel (045)322-107-1577 / (01)800-122-3355
        ";


    function SetWidths($w)
    {
        //Set the array of column widths
        $this->widths=$w;
    }

    function SetFill($f){
        $this->fill = $f;
    }

    function SetAligns($a)
    {
        //Set the array of column alignments
        $this->aligns=$a;
    }

    function Row($data)
    {
        //Calculate the height of the row
        $nb=0;
        for($i=0;$i<count($data);$i++)
            $nb=max($nb,$this->NbLines($this->widths[$i],$data[$i]));
        $h=5*$nb;
        //Issue a page break first if needed
        $this->CheckPageBreak($h);
        //Draw the cells of the row
        for($i=0;$i<count($data);$i++)
        {
            $w=$this->widths[$i];
            $a=isset($this->aligns[$i]) ? $this->aligns[$i] : 'L';
            $fill = isset($this->fill[$i]) ? $this->fill[$i] : false;
            //Save the current position
            $x=$this->GetX();
            $y=$this->GetY();
            //Draw the border
            $this->Rect($x,$y,$w,$h,$fill);
            //Print the text
            $this->MultiCell($w,5,$data[$i],0,$a,false);
            //Put the position to the right of the cell
            $this->SetXY($x+$w,$y);
        }
        //Go to the next line
        $this->Ln($h);
    }

    function CheckPageBreak($h)
    {
        //If the height h would cause an overflow, add a new page immediately
        if($this->GetY()+$h>$this->PageBreakTrigger)
            $this->AddPage($this->CurOrientation);
    }

    function NbLines($w,$txt)
    {
        //Computes the number of lines a MultiCell of width w will take
        $cw=&$this->CurrentFont['cw'];
        if($w==0)
            $w=$this->w-$this->rMargin-$this->x;
        $wmax=($w-2*$this->cMargin)*1000/$this->FontSize;
        $s=str_replace("\r",'',$txt);
        $nb=strlen($s);
        if($nb>0 and $s[$nb-1]=="\n")
            $nb--;
        $sep=-1;
        $i=0;
        $j=0;
        $l=0;
        $nl=1;
        while($i<$nb)
        {
            $c=$s[$i];
            if($c=="\n")
            {
                $i++;
                $sep=-1;
                $j=$i;
                $l=0;
                $nl++;
                continue;
            }
            if($c==' ')
                $sep=$i;
            $l+=$cw[$c];
            if($l>$wmax)
            {
                if($sep==-1)
                {
                    if($i==$j)
                        $i++;
                }
                else
                    $i=$sep+1;
                $sep=-1;
                $j=$i;
                $l=0;
                $nl++;
            }
            else
                $i++;
        }
        return $nl;
    }
    public function disclaimer(){
        $configurator = new Configurator();
        $configurator->loadConfig();
        $this->Ln(15);
        $this->SetFont('Arial','',9);
        $this->SetWidths(array(190));
        $this->SetTextColor(255,0,0);
        $this->SetTextColor(0,0,0);
        $this->SetFill(array('F'));
        $this->SetAligns(array("L"));
        $this->Row(array(utf8_decode($configurator->config['terms'])));
    }
    function productsListHeader(){
        $this->ln();
        $this->SetWidths(array(17,98,25,25,25));
        $this->SetAligns(array('C','C','C','C','C'));
        $this->SetFill(array('DF','DF','DF','DF','DF'));
        $this->Row(array('Cantidad',utf8_decode('Descripción'),'P/U Lista','Descuento','Importe'));
    }
    function productRow($product){
        $this->SetWidths(array(17,98,25,25,25));
        $this->SetAligns(array('C','C','R','R','R'));
        $this->SetFill(array(false,false,false,false,false,false));
        $this->Row(array($product['quantity'],$product['name'],"$".number_format($product['price'],2),"$".number_format($product['discount'],2),"$".number_format($product['total'],2)));
    }
}

class quotePdf extends PDF_MC_Table{

    function Header()
    {
        // Logo
        $this->SetWidths(array(50,90,50));
        $this->SetAligns(array('C','L','R'));
        $this->SetFont('Arial','',10);
        $this->Row(array($this->Image('modules/alm_quotes/file.jpg',10,13),$this->razonSocial." ".utf8_decode($this->direccion),utf8_decode("COTIZACIÓN \n Cot #").str_pad($GLOBALS['number'],5,0,STR_PAD_LEFT)));
        $this->Ln(10);
    }
    function addresses($obj){
        $this->SetAligns(array('C','C'));
        $this->SetWidths(array(95,95));
        $this->SetFont('Arial','B',10);
        $this->Row(array(utf8_decode('Datos de Facturación'),'Datos de Embarque'));
        $this->SetFont('Arial','',10);
        $this->SetAligns(array('L','L'));
        $billing = $obj->billing_address_street."\n".$obj->billing_address_city."\n ".$obj->billing_address_state."\n".$obj->billing_address_postalcode."\n".$obj->billing_address_country;
        $shipping = $obj->shipping_address_street."\n".$obj->shipping_address_city."\n ".$obj->shipping_address_state."\n".$obj->shipping_address_postalcode."\n".$obj->shipping_address_country;
        $this->Row(array(utf8_decode($billing),utf8_decode($shipping)));
    }
    function accountQuoteStatus($accountName,$quoteStatus,$contactName){
        $this->ln();
        $this->SetWidths(array(47.5,47.5,47.5,47.5));
        $this->SetAligns(array('R','L','R','L'));
        $this->SetFillColor(150,150,150);
        $this->SetFill(array('DF',false,'DF',false));
        $this->Row(array('Cuenta',$accountName,'Status',utf8_decode($quoteStatus)));
        $this->Row(array('Contacto',$contactName,'',''));
    }
    public function amounts($amounts){
        $this->Ln();
        $this->SetWidths(array(165,25));
        $this->SetAligns(array('R','R'));

        $this->SetFillColor(255,255,255);
        $this->SetFill(array('F','F'));
        $this->Row(array('Sub Total',"$".number_format($amounts->subtotal_c,2)));
        $this->Row(array('Descuento',"$".number_format($amounts->general_discount_c,2)));
        $this->Row(array('Impuesto',"$".number_format($amounts->taxes_c,2)));
        $this->Row(array('Total en dolares',"$".number_format($amounts->dollar_amount_c,2)));
    }
}

class sellPdf extends PDF_MC_Table{

    function Header()
    {
        // Logo
        $this->SetWidths(array(50,90,50));
        $this->SetAligns(array('C','L','R'));
        $this->SetFont('Arial','',10);
        $this->Row(array($this->Image('modules/alm_quotes/file.jpg',10,13),$this->razonSocial." ".
        utf8_decode($this->direccion),utf8_decode("ORDEN DE VENTA \n Venta #").
        str_pad($GLOBALS['number'],5,0,STR_PAD_LEFT)."\nFecha de entrega:\n".$this->deliveryDate()
        ));
        $this->Ln(10);
    }
    function deliveryDate(){

        $configurator = new Configurator();
        $configurator->loadConfig();
        $deliveryDays = ($GLOBALS['delivery_type'] == 'pre_pay')? $configurator->config['pre_pay_delivery']:$configurator->config['post_pay_delivery'];
        return $date = date("d-m-Y",strtotime(date("Y-m-d").' + '.$deliveryDays.' day'));die();
    }
    function address($address){
        $this->SetFont('Arial','',10);
        $this->SetWidths(array(190));
        $this->SetAligns(array('C'));
        $this->SetFillColor(150,150,150);
        $this->SetFill(array('DF'));
        $this->Row(array(utf8_decode("Dirección de envío")));

        $this->SetWidths(array(190));
        $this->SetAligns(array('L'));
        $this->SetFill(array(''));
        $this->Row(array(utf8_decode($address['address'])));
        $this->SetFillColor(255,255,255);
    }
    function contactData($contactInfo){
        $this->Ln();
        $custommer = $contactInfo['accountData'];
        $user = $contactInfo['sellerData'];
        $this->SetWidths(array(190));
        $this->SetAligns(array('C'));
        $this->SetFillColor(150,150,150);
        $this->SetFill(array('DF'));
        $this->Row(array(utf8_decode("Datos de contacto")));

        $this->SetWidths(array(47.5,47.5,47.5,47.5));
        $this->SetAligns(array('L','L'));
        $this->SetFillColor(150,150,150);
        $this->SetFill(array('DF','D','DF','D'));
        $this->Row(array('Cuenta',$custommer['contactData']['accountName'],'Vendedor',$user['userName']));
        $this->Row(array('Contacto',$custommer['contactData']['contactName'],'Vendedor',$user['userMail']));
    }
    function productList($products){
        foreach($products as $product){
            $this->productRow($product);
        }
    }
    function showComments($comments){
        $this->Ln();
        $this->SetWidths(array(190));
        $this->SetAligns(array("L"));
        $this->SetFillColor(255,255,255);
        $this->SetFill(array("F"));
        $this->Row(['Comentarios / Notas']);
        $this->Row(array($comments));
    }
}


?>